@@ -68,12 +68,12 @@ class DatabaseTrace(TimeTrace):
         database_name=None,
         **kwargs
     ):
-        parent = None
+        parent = kwargs.pop("parent", None)
+        source = kwargs.pop("source", None)
         if kwargs:
-            if len(kwargs) > 1:
-                raise TypeError("Invalid keyword arguments:", kwargs)
-            parent = kwargs["parent"]
-        super(DatabaseTrace, self).__init__(parent)
+            raise TypeError("Invalid keyword arguments:", kwargs)
+
+        super(DatabaseTrace, self).__init__(parent=parent, source=source)
 
         self.sql = sql
 
@@ -260,7 +260,7 @@ def DatabaseTraceWrapper(wrapped, sql, dbapi2_module=None):
         else:
             _sql = sql
 
-        trace = DatabaseTrace(_sql, dbapi2_module, parent=parent)
+        trace = DatabaseTrace(_sql, dbapi2_module, parent=parent, source=wrapped)
 
         if wrapper:  # pylint: disable=W0125,W0126
             return wrapper(wrapped, trace)(*args, **kwargs)
