@@ -25,12 +25,14 @@ import warnings
 import weakref
 from collections import OrderedDict
 
+from newrelic.api.application import application_instance
 import newrelic.core.database_node
 import newrelic.core.error_node
+from newrelic.core.log_event_node import LogEventNode
 import newrelic.core.root_node
 import newrelic.core.transaction_node
 import newrelic.packages.six as six
-from newrelic.api.time_trace import TimeTrace
+from newrelic.api.time_trace import TimeTrace, get_linking_metadata
 from newrelic.common.encoding_utils import (
     DistributedTracePayload,
     NrTraceState,
@@ -46,18 +48,20 @@ from newrelic.common.encoding_utils import (
     obfuscate,
 )
 from newrelic.core.attribute import (
+    MAX_LOG_MESSAGE_LENGTH,
     MAX_NUM_USER_ATTRIBUTES,
     create_agent_attributes,
     create_attributes,
     create_user_attributes,
     process_user_attribute,
+    truncate,
 )
 from newrelic.core.attribute_filter import (
     DST_ERROR_COLLECTOR,
     DST_NONE,
     DST_TRANSACTION_TRACER,
 )
-from newrelic.core.config import DEFAULT_RESERVOIR_SIZE
+from newrelic.core.config import DEFAULT_RESERVOIR_SIZE, LOG_EVENT_RESERVOIR_SIZE
 from newrelic.core.custom_event import create_custom_event
 from newrelic.core.stack_trace import exception_stack
 from newrelic.core.stats_engine import CustomMetrics, SampledDataSet
@@ -204,7 +208,6 @@ class Transaction(object):
 
         self._errors = []
         self._slow_sql = []
-        self._custom_events = SampledDataSet(capacity=DEFAULT_RESERVOIR_SIZE)
 
         self._stack_trace_count = 0
         self._explain_plan_count = 0
@@ -320,6 +323,13 @@ class Transaction(object):
                 if self._settings:
                     self.enabled = True
 
+        if self._settings:
+            self._custom_events = SampledDataSet(capacity=self._settings.event_harvest_config.harvest_limits.custom_event_data)
+            self._log_events = SampledDataSet(capacity=self._settings.event_harvest_config.harvest_limits.log_event_data)
+        else:
+            self._custom_events = SampledDataSet(capacity=DEFAULT_RESERVOIR_SIZE)
+            self._log_events = SampledDataSet(capacity=LOG_EVENT_RESERVOIR_SIZE)
+
     def __del__(self):
         self._dead = True
         if self._state == self.STATE_RUNNING:
@@ -562,6 +572,7 @@ class Transaction(object):
             errors=tuple(self._errors),
             slow_sql=tuple(self._slow_sql),
             custom_events=self._custom_events,
+            log_events=self._log_events,
             apdex_t=self.apdex,
             suppress_apdex=self.suppress_apdex,
             custom_metrics=self._custom_metrics,
@@ -979,7 +990,7 @@ class Transaction(object):
 
             self.ignore_transaction = self.ignore_transaction or ignore
 
-            # Apply segment whitelist rule to the segments on the full
+            # Apply segment allowlist rule to the segments on the full
             # transaction name. The path is frozen at this point and cannot be
             # further changed.
 
@@ -1465,6 +1476,31 @@ class Transaction(object):
         self._group = group
         self._name = name
 
+
+    def record_log_event(self, message, level=None, timestamp=None, priority=None):
+        settings = self.settings
+        if not (settings and settings.application_logging and settings.application_logging.enabled and settings.application_logging.forwarding and settings.application_logging.forwarding.enabled):
+            return
+        
+        timestamp = timestamp if timestamp is not None else time.time()
+        level = str(level) if level is not None else "UNKNOWN"
+        
+        if not message or message.isspace():
+            _logger.debug("record_log_event called where message was missing. No log event will be sent.")
+            return
+        
+        message = truncate(message, MAX_LOG_MESSAGE_LENGTH)
+
+        event = LogEventNode(
+            timestamp=timestamp,
+            level=level,
+            message=message,
+            attributes=get_linking_metadata(), 
+        )
+
+        self._log_events.add(event, priority=priority)
+
+
     def record_exception(self, exc=None, value=None, tb=None, params=None, ignore_errors=None):
         # Deprecation Warning
         warnings.warn(
@@ -1814,6 +1850,34 @@ def record_custom_event(event_type, params, application=None):
         application.record_custom_event(event_type, params)
 
 
+def record_log_event(message, level=None, timestamp=None, application=None, priority=None):
+    """Record a log event.
+
+    Args:
+        record (logging.Record):
+        application (newrelic.api.Application): Application instance.
+    """
+
+    if application is None:
+        transaction = current_transaction()
+        if transaction:
+            transaction.record_log_event(message, level, timestamp)
+        else:
+            application = application_instance(activate=False)
+
+            if application and application.enabled:
+                application.record_log_event(message, level, timestamp, priority=priority)
+            else:
+                _logger.debug(
+                    "record_log_event has been called but no transaction or application was running. As a result, "
+                    "the following event has not been recorded. message: %r level: %r timestamp %r. To correct "
+                    "this problem, supply an application object as a parameter to this record_log_event call.",
+                    message, level, timestamp,
+                )
+    elif application.enabled:
+        application.record_log_event(message, level, timestamp, priority=priority)
+
+
 def accept_distributed_trace_payload(payload, transport_type="HTTP"):
     transaction = current_transaction()
     if transaction:
