@@ -1,8 +1,22 @@
+# Copyright 2010 New Relic, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import functools
 
-from .transaction import current_transaction
-from ..common.object_wrapper import FunctionWrapper, wrap_object
-from ..common.object_names import callable_name
+from newrelic.api.transaction import current_transaction
+from newrelic.common.object_wrapper import FunctionWrapper, wrap_object
+from newrelic.common.object_names import callable_name
 
 def TransactionNameWrapper(wrapped, name=None, group=None, priority=None):
 
