@@ -177,7 +177,7 @@ class Application(object):
             print("URL Normalization Rules: %r" % (self._rules_engine["url"].rules), file=file)
             print("Metric Normalization Rules: %r" % (self._rules_engine["metric"].rules), file=file)
             print("Transaction Normalization Rules: %r" % (self._rules_engine["transaction"].rules), file=file)
-            print("Transaction Segment Whitelist Rules: %r" % (self._rules_engine["segment"].rules), file=file)
+            print("Transaction Segment Allowlist Rules: %r" % (self._rules_engine["segment"].rules), file=file)
             print("Harvest Period Start: %s" % (time.asctime(time.localtime(self._period_start))), file=file)
             print("Transaction Count: %d" % (self._transaction_count), file=file)
             print("Last Transaction: %s" % (time.asctime(time.localtime(self._last_transaction))), file=file)
@@ -537,6 +537,14 @@ class Application(object):
             )
             internal_metric("Supportability/Python/Application/Registration/Attempts", connect_attempts)
 
+            # Logging feature toggle supportability metrics
+            application_logging_metrics = configuration.application_logging.enabled and configuration.application_logging.metrics.enabled
+            application_logging_forwarding = configuration.application_logging.enabled and configuration.application_logging.forwarding.enabled
+            application_logging_local_decorating = configuration.application_logging.enabled and configuration.application_logging.local_decorating.enabled
+            internal_metric("Supportability/Logging/Forwarding/Python/%s" % ("enabled" if application_logging_forwarding else "disabled"), 1)
+            internal_metric("Supportability/Logging/LocalDecorating/Python/%s" % ("enabled" if application_logging_local_decorating else "disabled"), 1)
+            internal_metric("Supportability/Logging/Metrics/Python/%s" % ("enabled" if application_logging_metrics else "disabled"), 1)
+
         self._stats_engine.merge_custom_metrics(internal_metrics.metrics())
 
         # Update the active session in this object. This will the
@@ -836,6 +844,16 @@ class Application(object):
                 self._global_events_account += 1
                 self._stats_engine.record_custom_event(event)
 
+    def record_log_event(self, message, level=None, timestamp=None, priority=None):
+        if not self._active_session:
+            return
+
+        if message:
+            with self._stats_custom_lock:
+                event = self._stats_engine.record_log_event(message, level, timestamp, priority=priority)
+                if event:
+                    self._global_events_account += 1
+
     def record_transaction(self, data):
         """Record a single transaction against this application."""
 
@@ -1289,6 +1307,28 @@ class Application(object):
 
                             stats.reset_custom_events()
 
+                    # Send log events
+
+                    if configuration and configuration.application_logging and configuration.application_logging.enabled and configuration.application_logging.forwarding and configuration.application_logging.forwarding.enabled:
+
+                        logs = stats.log_events
+
+                        if logs:
+                            if logs.num_samples > 0:
+                                log_samples = list(logs)
+
+                                _logger.debug("Sending log event data for harvest of %r.", self._app_name)
+
+                                self._active_session.send_log_events(logs.sampling_info, log_samples)
+                                log_samples = None
+
+                            # As per spec
+                            internal_count_metric("Supportability/Logging/Forwarding/Seen", logs.num_seen)
+                            internal_count_metric("Supportability/Logging/Forwarding/Sent", logs.num_samples)
+                            internal_count_metric("Logging/Forwarding/Dropped", logs.num_seen - logs.num_samples)
+
+                            stats.reset_log_events()
+
                     # Send the accumulated error data.
 
                     if configuration.collect_errors:
