@@ -44,7 +44,7 @@ try:
     from newrelic.core.infinite_tracing_pb2 import (  # pylint: disable=W0611,C0412  # noqa: F401
         Span,
     )
-except ImportError:
+except Exception:
     grpc = None
 
 
@@ -54,6 +54,7 @@ except ImportError:
 DEFAULT_RESERVOIR_SIZE = 1200
 ERROR_EVENT_RESERVOIR_SIZE = 100
 SPAN_EVENT_RESERVOIR_SIZE = 2000
+LOG_EVENT_RESERVOIR_SIZE = 10000
 
 # settings that should be completely ignored if set server side
 IGNORED_SERVER_SIDE_SETTINGS = [
@@ -259,6 +260,22 @@ class EventLoopVisibilitySettings(Settings):
     pass
 
 
+class ApplicationLoggingSettings(Settings):
+    pass
+
+
+class ApplicationLoggingForwardingSettings(Settings):
+    pass
+
+
+class ApplicationLoggingMetricsSettings(Settings):
+    pass
+
+
+class ApplicationLoggingLocalDecoratingSettings(Settings):
+    pass
+
+
 class InfiniteTracingSettings(Settings):
     _trace_observer_host = None
 
@@ -337,6 +354,10 @@ class EventHarvestConfigHarvestLimitSettings(Settings):
 
 
 _settings = TopLevelSettings()
+_settings.application_logging = ApplicationLoggingSettings()
+_settings.application_logging.forwarding = ApplicationLoggingForwardingSettings()
+_settings.application_logging.metrics = ApplicationLoggingMetricsSettings()
+_settings.application_logging.local_decorating = ApplicationLoggingLocalDecoratingSettings()
 _settings.attributes = AttributesSettings()
 _settings.gc_runtime_metrics = GCRuntimeMetricsSettings()
 _settings.code_level_metrics = CodeLevelMetricsSettings()
@@ -728,6 +749,10 @@ _settings.event_harvest_config.harvest_limits.error_event_data = _environ_as_int
     "NEW_RELIC_ERROR_COLLECTOR_MAX_EVENT_SAMPLES_STORED", ERROR_EVENT_RESERVOIR_SIZE
 )
 
+_settings.event_harvest_config.harvest_limits.log_event_data = _environ_as_int(
+    "NEW_RELIC_APPLICATION_LOGGING_FORWARDING_MAX_SAMPLES_STORED", LOG_EVENT_RESERVOIR_SIZE
+)
+
 _settings.console.listener_socket = None
 _settings.console.allow_interpreter_cmd = False
 
@@ -768,7 +793,7 @@ _settings.utilization.total_ram_mib = _environ_as_int("NEW_RELIC_UTILIZATION_TOT
 _settings.utilization.billing_hostname = os.environ.get("NEW_RELIC_UTILIZATION_BILLING_HOSTNAME")
 
 _settings.strip_exception_messages.enabled = False
-_settings.strip_exception_messages.whitelist = []
+_settings.strip_exception_messages.allowlist = []
 
 _settings.datastore_tracer.instance_reporting.enabled = True
 _settings.datastore_tracer.database_name_reporting.enabled = True
@@ -785,6 +810,17 @@ _settings.event_loop_visibility.enabled = True
 _settings.event_loop_visibility.blocking_threshold = 0.1
 _settings.code_level_metrics.enabled = True
 
+_settings.application_logging.enabled = _environ_as_bool("NEW_RELIC_APPLICATION_LOGGING_ENABLED", default=True)
+_settings.application_logging.forwarding.enabled = _environ_as_bool(
+    "NEW_RELIC_APPLICATION_LOGGING_FORWARDING_ENABLED", default=False
+)
+_settings.application_logging.metrics.enabled = _environ_as_bool(
+    "NEW_RELIC_APPLICATION_LOGGING_METRICS_ENABLED", default=True
+)
+_settings.application_logging.local_decorating.enabled = _environ_as_bool(
+    "NEW_RELIC_APPLICATION_LOGGING_LOCAL_DECORATING_ENABLED", default=False
+)
+
 
 def global_settings():
     """This returns the default global settings. Generally only used
@@ -1037,7 +1073,7 @@ def apply_server_side_settings(server_side_config=None, settings=_settings):
 
     event_harvest_config = server_side_config.get("event_harvest_config", {})
     harvest_limits = event_harvest_config.get("harvest_limits", ())
-    apply_config_setting(settings_snapshot, "event_harvest_config.whitelist", frozenset(harvest_limits))
+    apply_config_setting(settings_snapshot, "event_harvest_config.allowlist", frozenset(harvest_limits))
 
     # Override span event harvest config
     span_event_harvest_config = server_side_config.get("span_event_harvest_config", {})
