@@ -32,17 +32,19 @@ from heapq import heapify, heapreplace
 
 import newrelic.packages.six as six
 from newrelic.api.settings import STRIP_EXCEPTION_MESSAGE
+from newrelic.api.time_trace import get_linking_metadata
 from newrelic.common.encoding_utils import json_encode
 from newrelic.common.object_names import parse_exc_info
 from newrelic.common.streaming_utils import StreamBuffer
-from newrelic.core.attribute import create_user_attributes, process_user_attribute
+from newrelic.core.attribute import create_user_attributes, process_user_attribute, truncate, MAX_LOG_MESSAGE_LENGTH
 from newrelic.core.attribute_filter import DST_ERROR_COLLECTOR
+from newrelic.core.code_level_metrics import extract_code_from_traceback
 from newrelic.core.config import is_expected_error, should_ignore_error
 from newrelic.core.database_utils import explain_plan
 from newrelic.core.error_collector import TracedError
 from newrelic.core.metric import TimeMetric
-from newrelic.core.code_level_metrics import extract_code_from_traceback
 from newrelic.core.stack_trace import exception_stack
+from newrelic.core.log_event_node import LogEventNode
 
 _logger = logging.getLogger(__name__)
 
@@ -54,6 +56,7 @@ EVENT_HARVEST_METHODS = {
     "span_event_data": ("reset_span_events",),
     "custom_event_data": ("reset_custom_events",),
     "error_event_data": ("reset_error_events",),
+    "log_event_data": ("reset_log_events",),
 }
 
 
@@ -331,9 +334,12 @@ class SampledDataSet(object):
                 return
             heapreplace(self.pq, entry)
 
-    def merge(self, other_data_set):
-        for priority, seen_at, sample in other_data_set.pq:
-            self.add(sample, priority)
+    def merge(self, other_data_set, priority=None):
+        if priority is None:
+            priority = -1
+
+        for original_priority, seen_at, sample in other_data_set.pq:
+            self.add(sample, max(priority, original_priority))
 
         # Merge the num_seen from the other_data_set, but take care not to
         # double-count the actual samples of other_data_set since the .add
@@ -424,6 +430,7 @@ class StatsEngine(object):
         self._error_events = SampledDataSet()
         self._custom_events = SampledDataSet()
         self._span_events = SampledDataSet()
+        self._log_events = SampledDataSet()
         self._span_stream = None
         self.__sql_stats_table = {}
         self.__slow_transaction = None
@@ -454,6 +461,10 @@ class StatsEngine(object):
     def span_events(self):
         return self._span_events
 
+    @property
+    def log_events(self):
+        return self._log_events
+
     @property
     def span_stream(self):
         return self._span_stream
@@ -599,7 +610,7 @@ class StatsEngine(object):
 
         # Check to see if we need to strip the message before recording it.
 
-        if settings.strip_exception_messages.enabled and fullname not in settings.strip_exception_messages.whitelist:
+        if settings.strip_exception_messages.enabled and fullname not in settings.strip_exception_messages.allowlist:
             message = STRIP_EXCEPTION_MESSAGE
 
         # Where expected or ignore are a callable they should return a
@@ -718,7 +729,6 @@ class StatsEngine(object):
         if settings and settings.code_level_metrics and settings.code_level_metrics.enabled:
             extract_code_from_traceback(tb).add_attrs(attributes["agentAttributes"].__setitem__)
 
-
         error_details = TracedError(
             start_time=time.time(), path="Exception", message=message, type=fullname, parameters=attributes
         )
@@ -996,6 +1006,42 @@ class StatsEngine(object):
                 for event in transaction.span_events(self.__settings):
                     self._span_events.add(event, priority=transaction.priority)
 
+        # Merge in log events
+
+        if settings and settings.application_logging and settings.application_logging.enabled and settings.application_logging.forwarding and settings.application_logging.forwarding.enabled:
+            self._log_events.merge(transaction.log_events, priority=transaction.priority)
+
+
+    def record_log_event(self, message, level=None, timestamp=None, priority=None):
+        settings = self.__settings
+        if not (settings and settings.application_logging and settings.application_logging.enabled and settings.application_logging.forwarding and settings.application_logging.forwarding.enabled):
+            return
+        
+        timestamp = timestamp if timestamp is not None else time.time()
+        level = str(level) if level is not None else "UNKNOWN"
+
+        if not message or message.isspace():
+            _logger.debug("record_log_event called where message was missing. No log event will be sent.")
+            return
+        
+        message = truncate(message, MAX_LOG_MESSAGE_LENGTH)
+
+        event = LogEventNode(
+            timestamp=timestamp,
+            level=level,
+            message=message,
+            attributes=get_linking_metadata(), 
+        )
+
+        if priority is None:
+            # Base priority for log events outside transactions is below those inside transactions
+            priority = random.random() - 1
+
+        self._log_events.add(event, priority=priority)
+
+        return event
+
+
     def metric_data(self, normalizer=None):
         """Returns a list containing the low level metric data for
         sending to the core application pertaining to the reporting
@@ -1348,6 +1394,7 @@ class StatsEngine(object):
         self.reset_error_events()
         self.reset_custom_events()
         self.reset_span_events()
+        self.reset_log_events()
         self.reset_synthetics_events()
         # streams are never reset after instantiation
         if reset_stream:
@@ -1392,6 +1439,12 @@ class StatsEngine(object):
         else:
             self._span_events = SampledDataSet()
 
+    def reset_log_events(self):
+        if self.__settings is not None:
+            self._log_events = SampledDataSet(self.__settings.event_harvest_config.harvest_limits.log_event_data)
+        else:
+            self._log_events = SampledDataSet()
+
     def reset_synthetics_events(self):
         """Resets the accumulated statistics back to initial state for
         Synthetics events data.
@@ -1458,28 +1511,28 @@ class StatsEngine(object):
         # represented in either the snapshot or in the current stats object.
         #
         #   If we're in flexible harvest, the goal is to have everything in the
-        #   whitelist appear in the snapshot. This means, we must remove the
-        #   whitelist data types from the current stats object.
+        #   allowlist appear in the snapshot. This means, we must remove the
+        #   allowlist data types from the current stats object.
         #
         #   If we're not in flexible harvest, everything excluded from the
-        #   whitelist appears in the snapshot and is removed from the current
+        #   allowlist appears in the snapshot and is removed from the current
         #   stats object.
         if flexible:
-            whitelist_stats, other_stats = self, snapshot
+            allowlist_stats, other_stats = self, snapshot
             snapshot.reset_non_event_types()
         else:
-            whitelist_stats, other_stats = snapshot, self
+            allowlist_stats, other_stats = snapshot, self
             self.reset_non_event_types()
 
-        event_harvest_whitelist = self.__settings.event_harvest_config.whitelist
+        event_harvest_allowlist = self.__settings.event_harvest_config.allowlist
 
         # Iterate through harvest types. If they are in the list of types to
         # harvest reset them on stats_engine otherwise remove them from the
         # snapshot.
         for nr_method, stats_methods in EVENT_HARVEST_METHODS.items():
             for stats_method in stats_methods:
-                if nr_method in event_harvest_whitelist:
-                    reset = getattr(whitelist_stats, stats_method)
+                if nr_method in event_harvest_allowlist:
+                    reset = getattr(allowlist_stats, stats_method)
                 else:
                     reset = getattr(other_stats, stats_method)
 
@@ -1514,6 +1567,7 @@ class StatsEngine(object):
         self._merge_error_traces(snapshot)
         self._merge_custom_events(snapshot)
         self._merge_span_events(snapshot)
+        self._merge_log_events(snapshot)
         self._merge_sql(snapshot)
         self._merge_traces(snapshot)
 
@@ -1538,6 +1592,7 @@ class StatsEngine(object):
         self._merge_error_events(snapshot)
         self._merge_custom_events(snapshot, rollback=True)
         self._merge_span_events(snapshot, rollback=True)
+        self._merge_log_events(snapshot, rollback=True)
 
     def merge_metric_stats(self, snapshot):
         """Merges metric data from a snapshot. This is used both when merging
@@ -1614,6 +1669,12 @@ class StatsEngine(object):
             return
         self._span_events.merge(events)
 
+    def _merge_log_events(self, snapshot, rollback=False):
+        events = snapshot.log_events
+        if not events:
+            return
+        self._log_events.merge(events)
+
     def _merge_error_traces(self, snapshot):
 
         # Append snapshot error details at end to maintain time
@@ -1690,6 +1751,9 @@ class StatsEngineSnapshot(StatsEngine):
     def reset_span_events(self):
         self._span_events = None
 
+    def reset_log_events(self):
+        self._log_events = None
+
     def reset_synthetics_events(self):
         self._synthetics_events = None
 
