@@ -41,8 +41,8 @@ _TransactionNode = namedtuple('_TransactionNode',
         'port', 'request_uri', 'queue_start', 'start_time',
         'end_time', 'last_byte_time', 'response_time', 'total_time',
         'duration', 'exclusive', 'root', 'errors', 'slow_sql',
-        'custom_events', 'apdex_t', 'suppress_apdex', 'custom_metrics', 'guid',
-        'cpu_time', 'suppress_transaction_trace', 'client_cross_process_id',
+        'custom_events', 'log_events', 'apdex_t', 'suppress_apdex', 'custom_metrics',
+        'guid', 'cpu_time', 'suppress_transaction_trace', 'client_cross_process_id',
         'referring_transaction_guid', 'record_tt', 'synthetics_resource_id',
         'synthetics_job_id', 'synthetics_monitor_id', 'synthetics_header',
         'is_part_of_cat', 'trip_id', 'path_hash', 'referring_path_hash',
