@@ -12,9 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import sys
-import types
-
 import newrelic.api.transaction
 import newrelic.api.transaction_name
 import newrelic.api.function_trace
