@@ -13,10 +13,11 @@
 # limitations under the License.
 
 import sys
+from inspect import isawaitable
 
 from newrelic.api.web_transaction import web_transaction
 from newrelic.api.transaction import current_transaction
-from newrelic.api.function_trace import function_trace
+from newrelic.api.function_trace import function_trace, FunctionTrace
 from newrelic.api.time_trace import notice_error
 from newrelic.common.object_wrapper import (wrap_function_wrapper,
     function_wrapper)
@@ -36,16 +37,21 @@ def _nr_wrapper_handler_(wrapped, instance, args, kwargs):
 
     name = callable_name(wrapped)
     view_class = getattr(wrapped, 'view_class', None)
+    view = view_class or wrapped
     if view_class:
         try:
             method = args[0].method.lower()
             name = callable_name(view_class) + '.' + method
+            view = getattr(view_class, method)
         except:
             pass
+    
     transaction.set_transaction_name(name, priority=3)
     import sanic
     transaction.add_framework_info(name='Sanic', version=sanic.__version__)
-    return function_trace(name=name)(wrapped)(*args, **kwargs)
+
+    with FunctionTrace(name=name, source=view):
+        return wrapped(*args, **kwargs)
 
 
 @function_wrapper
@@ -157,6 +163,44 @@ def _sanic_app_init(wrapped, instance, args, kwargs):
     return result
 
 
+def _nr_sanic_response_get_headers(wrapped, instance, args, kwargs):
+    # We call the wrapped function twice to allow the function to mutate the headers
+    result = wrapped(*args, **kwargs)
+    transaction = current_transaction()
+
+    if transaction is None:
+        return result
+
+    # instance is the response object
+    cat_headers = transaction.process_response(str(instance.status),
+            instance.headers.items())
+
+    for header_name, header_value in cat_headers:
+        if header_name not in instance.headers:
+            instance.headers[header_name] = header_value
+
+    return wrapped(*args, **kwargs)
+
+
+async def _nr_sanic_response_send(wrapped, instance, args, kwargs):
+    transaction = current_transaction()
+    result = wrapped(*args, **kwargs)
+    if isawaitable(result):
+        await result
+
+    if transaction is None:
+        return wrapped(*args, **kwargs)
+
+    # instance is the response object
+    cat_headers = transaction.process_response(str(instance.status),
+            instance.headers.items())
+
+    for header_name, header_value in cat_headers:
+        if header_name not in instance.headers:
+            instance.headers[header_name] = header_value
+
+    return result
+
 def _nr_sanic_response_parse_headers(wrapped, instance, args, kwargs):
     transaction = current_transaction()
 
@@ -232,8 +276,19 @@ def instrument_sanic_app(module):
         _sanic_app_init)
     wrap_function_wrapper(module, 'Sanic.register_middleware',
         _nr_sanic_register_middleware_)
+    if hasattr(module.Sanic, 'register_named_middleware'):
+        wrap_function_wrapper(module, 'Sanic.register_named_middleware',
+            _nr_sanic_register_middleware_)
 
 
 def instrument_sanic_response(module):
-    wrap_function_wrapper(module, 'BaseHTTPResponse._parse_headers',
-        _nr_sanic_response_parse_headers)
+    if hasattr(module.BaseHTTPResponse, 'send'):
+        wrap_function_wrapper(module, 'BaseHTTPResponse.send',
+            _nr_sanic_response_send)
+    else:
+        if hasattr(module.BaseHTTPResponse, 'get_headers'):
+            wrap_function_wrapper(module, 'BaseHTTPResponse.get_headers',
+                _nr_sanic_response_get_headers)
+        if hasattr(module.BaseHTTPResponse, '_parse_headers'):
+            wrap_function_wrapper(module, 'BaseHTTPResponse._parse_headers',
+                _nr_sanic_response_parse_headers)
