@@ -17,6 +17,7 @@ import pytest
 from testing_support.fixtures import (validate_transaction_metrics,
     validate_transaction_errors, override_application_settings,
     validate_tt_parenting)
+from testing_support.validators.validate_code_level_metrics import validate_code_level_metrics
 
 from newrelic.packages import six
 
@@ -96,6 +97,7 @@ if is_dev_version or (is_gt_flask060 and flask_version >= (0, 9)):
 @validate_transaction_metrics('_test_application:index_page',
         scoped_metrics=_test_application_index_scoped_metrics)
 @validate_tt_parenting(_test_application_index_tt_parenting)
+@validate_code_level_metrics("_test_application", "index_page")
 def test_application_index():
     application = target_application()
     response = application.get('/index')
@@ -114,6 +116,7 @@ _test_application_async_scoped_metrics = [
 @validate_transaction_metrics('_test_application_async:async_page',
         scoped_metrics=_test_application_async_scoped_metrics)
 @validate_tt_parenting(_test_application_index_tt_parenting)
+@validate_code_level_metrics("_test_application_async", "async_page")
 def test_application_async():
     application = target_application()
     response = application.get('/async')
@@ -131,6 +134,7 @@ _test_application_endpoint_scoped_metrics = [
 @validate_transaction_errors(errors=[])
 @validate_transaction_metrics('_test_application:endpoint_page',
         scoped_metrics=_test_application_endpoint_scoped_metrics)
+@validate_code_level_metrics("_test_application", "endpoint_page")
 def test_application_endpoint():
     application = target_application()
     response = application.get('/endpoint')
@@ -158,6 +162,7 @@ else:
 @validate_transaction_errors(errors=_test_application_error_errors)
 @validate_transaction_metrics('_test_application:error_page',
         scoped_metrics=_test_application_error_scoped_metrics)
+@validate_code_level_metrics("_test_application", "error_page")
 def test_application_error():
     application = target_application()
     application.get('/error', status=500, expect_errors=True)
@@ -177,6 +182,7 @@ _test_application_abort_404_scoped_metrics = [
 @validate_transaction_errors(errors=[])
 @validate_transaction_metrics('_test_application:abort_404_page',
         scoped_metrics=_test_application_abort_404_scoped_metrics)
+@validate_code_level_metrics("_test_application", "abort_404_page")
 def test_application_abort_404():
     application = target_application()
     application.get('/abort_404', status=404)
@@ -196,6 +202,7 @@ _test_application_exception_404_scoped_metrics = [
 @validate_transaction_errors(errors=[])
 @validate_transaction_metrics('_test_application:exception_404_page',
         scoped_metrics=_test_application_exception_404_scoped_metrics)
+@validate_code_level_metrics("_test_application", "exception_404_page")
 def test_application_exception_404():
     application = target_application()
     application.get('/exception_404', status=404)
@@ -233,6 +240,7 @@ _test_application_render_template_string_scoped_metrics = [
 @validate_transaction_errors(errors=[])
 @validate_transaction_metrics('_test_application:template_string',
         scoped_metrics=_test_application_render_template_string_scoped_metrics)
+@validate_code_level_metrics("_test_application", "template_string")
 def test_application_render_template_string():
     application = target_application()
     application.get('/template_string')
