@@ -66,12 +66,12 @@ def to_graphql_source(query):
     return delay_import
 
 
-def example_middleware(next, root, info, **args):  #pylint: disable=W0622
+def example_middleware(next, root, info, **args):  # pylint: disable=W0622
     return_value = next(root, info, **args)
     return return_value
 
 
-def error_middleware(next, root, info, **args):  #pylint: disable=W0622
+def error_middleware(next, root, info, **args):  # pylint: disable=W0622
     raise RuntimeError("Runtime Error!")
 
 
@@ -88,12 +88,12 @@ _graphql_base_rollup_metrics = [
 
 def test_basic(app, graphql_run):
     from graphql import __version__ as version
-    from newrelic.hooks.framework_graphql import graphene_framework_details
+
+    from newrelic.hooks.framework_graphene import framework_details
 
     FRAMEWORK_METRICS = [
-        ("Python/Framework/Graphene/%s" % graphene_framework_details()[1], 1),
+        ("Python/Framework/Graphene/%s" % framework_details()[1], 1),
         ("Python/Framework/GraphQL/%s" % version, 1),
-
     ]
 
     @validate_transaction_metrics(
@@ -192,8 +192,8 @@ def test_middleware(app, graphql_run, is_graphql_2):
         rollup_metrics=_test_middleware_metrics + _graphql_base_rollup_metrics,
         background_task=True,
     )
-    # Span count 4: Transaction, Operation, Middleware, and 1 Resolver
-    @validate_span_events(count=4)
+    # Span count 5: Transaction, Operation, Middleware, and 1 Resolver and 1 Resolver Function
+    @validate_span_events(count=5)
     @background_task()
     def _test():
         response = graphql_run(app, "{ hello }", middleware=[example_middleware])
@@ -326,7 +326,7 @@ def test_exception_in_validation(app, graphql_run, is_graphql_2, query, exc_clas
         exc_class = callable_name(GraphQLError)
 
     _test_exception_scoped_metrics = [
-            ('GraphQL/operation/Graphene/<unknown>/<anonymous>/<unknown>', 1),
+        ("GraphQL/operation/Graphene/<unknown>/<anonymous>/<unknown>", 1),
     ]
     _test_exception_rollup_metrics = [
         ("Errors/all", 1),
@@ -373,10 +373,10 @@ def test_operation_metrics_and_attrs(app, graphql_run):
         rollup_metrics=operation_metrics + _graphql_base_rollup_metrics,
         background_task=True,
     )
-    # Span count 7: Transaction, Operation, and 7 Resolvers
+    # Span count 16: Transaction, Operation, and 7 Resolvers and Resolver functions
     # library, library.name, library.book
     # library.book.name and library.book.id for each book resolved (in this case 2)
-    @validate_span_events(count=9)
+    @validate_span_events(count=16)
     @validate_span_events(exact_agents=operation_attrs)
     @background_task()
     def _test():
@@ -403,8 +403,8 @@ def test_field_resolver_metrics_and_attrs(app, graphql_run):
         rollup_metrics=field_resolver_metrics + _graphql_base_rollup_metrics,
         background_task=True,
     )
-    # Span count 3: Transaction, Operation, and 1 Resolver
-    @validate_span_events(count=3)
+    # Span count 4: Transaction, Operation, and 1 Resolver and Resolver function
+    @validate_span_events(count=4)
     @validate_span_events(exact_agents=graphql_attrs)
     @background_task()
     def _test():
