@@ -22,6 +22,7 @@ from testing_support.validators.validate_span_events import validate_span_events
 from testing_support.validators.validate_transaction_count import (
     validate_transaction_count,
 )
+from testing_support.validators.validate_code_level_metrics import validate_code_level_metrics
 
 from newrelic.api.background_task import background_task
 from newrelic.common.object_names import callable_name
@@ -148,6 +149,8 @@ def test_query_and_mutation(app, graphql_run, is_graphql_2):
         "graphql.field.returnType": "[String]",
     }
 
+    @validate_code_level_metrics("_target_application", "resolve_storage")
+    @validate_code_level_metrics("_target_application", "resolve_storage_add")
     @validate_transaction_metrics(
         "query/<anonymous>/storage",
         "GraphQL",
@@ -181,6 +184,8 @@ def test_middleware(app, graphql_run, is_graphql_2):
         ("Function/test_application:example_middleware", 1),
     ]
 
+    @validate_code_level_metrics("test_application", "example_middleware")
+    @validate_code_level_metrics("_target_application", "resolve_hello")
     @validate_transaction_metrics(
         "query/<anonymous>/hello",
         "GraphQL",
@@ -188,8 +193,8 @@ def test_middleware(app, graphql_run, is_graphql_2):
         rollup_metrics=_test_middleware_metrics + _graphql_base_rollup_metrics,
         background_task=True,
     )
-    # Span count 4: Transaction, Operation, Middleware, and 1 Resolver
-    @validate_span_events(count=4)
+    # Span count 5: Transaction, Operation, Middleware, and 1 Resolver and Resolver Function
+    @validate_span_events(count=5)
     @background_task()
     def _test():
         response = graphql_run(app, "{ hello }", middleware=[example_middleware])
@@ -366,10 +371,10 @@ def test_operation_metrics_and_attrs(app, graphql_run):
         rollup_metrics=operation_metrics + _graphql_base_rollup_metrics,
         background_task=True,
     )
-    # Span count 7: Transaction, Operation, and 7 Resolvers
+    # Span count 16: Transaction, Operation, and 7 Resolvers and Resolver functions
     # library, library.name, library.book
     # library.book.name and library.book.id for each book resolved (in this case 2)
-    @validate_span_events(count=9)
+    @validate_span_events(count=16)
     @validate_span_events(exact_agents=operation_attrs)
     @background_task()
     def _test():
@@ -398,8 +403,8 @@ def test_field_resolver_metrics_and_attrs(app, graphql_run):
         rollup_metrics=field_resolver_metrics + _graphql_base_rollup_metrics,
         background_task=True,
     )
-    # Span count 3: Transaction, Operation, and 1 Resolver
-    @validate_span_events(count=3)
+    # Span count 4: Transaction, Operation, and 1 Resolver and Resolver function
+    @validate_span_events(count=4)
     @validate_span_events(exact_agents=graphql_attrs)
     @background_task()
     def _test():
